core library
Classes
- AltInputHandler
- Translates Alt plus printable text into legacy terminal input.
- ApplicationKeypadInputHandler
- Translates numpad keys in application keypad mode.
- BackspaceInputHandler
- Translates Backspace according to DEC Backarrow Key Mode (DECBKM).
- Buffer
- BufferLine
- BufferRange
- BufferRangeBlock
- BufferRangeLine
- BufferSegment
- A BufferSegment represents a range within a line.
- CascadeInputHandler
- Chains input handlers and returns the first non-null result.
- CascadeMouseHandler
- CellAnchor
- A handle to a cell in a BufferLine that can be used to track the location of the cell. Anchors are guaranteed to be stable, retaining their relative position to each other after mutations to the buffer.
- CellAttr
- CellColor
- CellContent
- CellData
- CellFlags
- CellOffset
- ClickMouseHandler
- CtrlInputHandler
- Translates Ctrl plus a letter into a C0 control character.
- CursorPosition
- CursorStyle
- EscapeHandler
- EscapeParser
- EscapeParser translates control characters and escape sequences into function calls that the terminal can handle.
- EscapeTextHandler
- ExtendedFunctionKeyInputHandler
- Translates F13-F24 to the xterm-compatible shifted F1-F12 sequences.
- KeytabInputHandler
- Translates key events according to a keytab file.
- KittyKeyboardInputHandler
- Translates key presses using Kitty's progressive keyboard protocol.
- ModifyOtherKeysInputHandler
- Translates textual keys using xterm modifyOtherKeys mode 2.
- NamedColor
- Terminal
- Terminal is an interface to interact with command line applications. It translates escape sequences from the application into updates to the buffer and events such as onTitleChange or onBell, as well as translating user input into escape sequences that the application can understand.
- TerminalContextSignal
- A hierarchical context update reported through OSC 3008.
- TerminalInputHandler
- Translates a keyboard event into an escape sequence for the terminal.
- TerminalKeyboardEvent
- The key event received from the keyboard, along with the state of the modifier keys and state of the terminal. Typically consumed by the TerminalInputHandler to produce an escape sequence that can be recognized by the terminal.
- TerminalMouseEvent
- TerminalMouseHandler
- TerminalMouseModifiers
- TerminalProgressReport
- TerminalSearchMatch
- A terminal buffer search match.
- TerminalSemanticPromptState
- TerminalState
- UpDownMouseHandler
Enums
- MouseMode
- https://terminalguide.namepad.de/mouse/
- MouseReportMode
- https://terminalguide.namepad.de/mouse/
- TerminalColorScheme
- TerminalContextExitStatus
- TerminalContextSignalAction
- TerminalContextType
- TerminalCursorType
- TerminalKey
- TerminalKeyEventType
- TerminalMouseButton
- TerminalMouseButtonState
- TerminalProgressState
- TerminalSemanticPromptClickMode
- TerminalSemanticPromptContent
- TerminalSemanticPromptKind
- TerminalSemanticPromptRedraw
- TerminalTargetPlatform
Extensions
- TerminalSearch on Terminal
- Search support for terminal scrollback and the active viewport.
Constants
- defaultInputHandler → const CascadeInputHandler
- The default terminal input handler chain.
- defaultMouseHandler → const CascadeMouseHandler