Buffer class
Methods
backIndex ()
→ void
backspace ()
→ void
carriageReturn ()
→ void
changeRectAttributes (int top , int left , int bottom , int right , int attribute , {required bool rectangular })
→ void
clear ()
→ void
Clears the viewport and scrollback buffer. Then fill with empty lines.
clearSavedCursorHyperlink ()
→ void
clearScrollback ()
→ void
Remove all lines above the top of the viewport.
copyRect (int sourceTop , int sourceLeft , int sourceBottom , int sourceRight , int sourcePage , int destinationTop , int destinationLeft , int destinationPage )
→ void
createAnchor (int x , int y )
→ CellAnchor
Create a new CellAnchor at the specified x and y coordinates.
createAnchorFromCursor ()
→ CellAnchor
createAnchorFromOffset (CellOffset offset )
→ CellAnchor
Create a new CellAnchor at the specified x and y coordinates.
cursorGoForward ()
→ void
deleteChars (int count )
→ void
deleteColumns (int count )
→ void
deleteLines (int count )
→ void
Remove count lines starting at the current cursor position. Lines below
the removed lines are shifted up. This only affects the scrollable region.
Lines outside the scrollable region are not affected.
eraseChars (int count , {bool respectProtected = false })
→ void
Erases count cells starting at the cursor position.
eraseDisplay ({bool respectProtected = false })
→ void
Erases the whole viewport.
eraseDisplayFromCursor ({bool respectProtected = false })
→ void
Erases the viewport from the cursor position to the end of the buffer,
including the cursor position.
eraseDisplayToCursor ({bool respectProtected = false })
→ void
Erases the viewport from the top-left corner to the cursor, including the
cursor.
eraseLine ({bool respectProtected = false })
→ void
Erases the line at the current cursor position.
eraseLineFromCursor ({bool respectProtected = false })
→ void
Erases the line from the cursor to the end of the line, including the
cursor position.
eraseLineToCursor ({bool respectProtected = false })
→ void
Erases the line from the start of the line to the cursor, including the
cursor.
eraseRect (int top , int left , int bottom , int right , {bool respectProtected = false })
→ void
fillRect (int char , int top , int left , int bottom , int right )
→ void
forwardIndex ()
→ void
getText ([BufferRange ? range ])
→ String
Get the plain text content of the buffer including the scrollback.
Accepts an optional range to get a specific part of the buffer.
getWordBoundary (CellOffset position )
→ BufferRangeLine ?
index ()
→ void
https://vt100.net/docs/vt100-ug/chapter3.html#IND IND – Index
insertBlankChars (int count )
→ void
insertColumns (int count )
→ void
insertLines (int count )
→ void
lineFeed ()
→ void
moveCursor (int offsetX , int offsetY )
→ void
moveCursorX (int offset )
→ void
moveCursorY (int offset )
→ void
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset ()
→ void
resetHorizontalMargins ()
→ void
resetVerticalMargins ()
→ void
resetViewport ()
→ void
resize (int oldWidth , int oldHeight , int newWidth , int newHeight )
→ void
restoreCursor ()
→ bool
Restore cursor position, charmap and text attributes.
reverseIndex ()
→ void
https://terminalguide.namepad.de/seq/a_esc_cm/
reverseRectAttributes (int top , int left , int bottom , int right , int attribute , {required bool rectangular })
→ void
saveCursor ({required bool originMode })
→ void
Save cursor position, charmap and text attributes.
screenAlignmentTest ()
→ void
scrollDown (int count )
→ void
scrollUp (int count )
→ void
setCursor (int cursorX , int cursorY )
→ void
setCursorX (int cursorX )
→ void
setCursorY (int cursorY )
→ void
setHorizontalMargins (int left , int right )
→ void
Sets the horizontal scrolling margin to left and right.
Both values must be between 0 and viewWidth - 1.
setVerticalMargins (int top , int bottom )
→ void
Sets the vertical scrolling margin to top and bottom.
Both values must be between 0 and viewHeight - 1.
toString ()
→ String
Returns a debug representation of the buffer.
override
write (String text )
→ void
Writes data to the _terminal. Terminal sequences or special characters are
not interpreted and directly added to the buffer.
writeChar (int codePoint )
→ void
Writes a single character to the _terminal. Escape sequences or special
characters are not interpreted and directly added to the buffer.