forceScrollToBottomGeneration property

int get forceScrollToBottomGeneration

Increments when terminal-originated actions should force the viewport to the bottom even if the user was previously scrolled up.

Implementation

int get forceScrollToBottomGeneration => _forceScrollToBottomGeneration;