lines property
lines of the buffer. the length of lines should always be equal or greater than viewHeight.
Implementation
late final lines = IndexAwareCircularBuffer<BufferLine>(
max(maxLines, terminal.viewHeight),
);
lines of the buffer. the length of lines should always be equal or greater than viewHeight.
late final lines = IndexAwareCircularBuffer<BufferLine>(
max(maxLines, terminal.viewHeight),
);