extend abstract method
Returns the smallest range that contains both this range and the given
position.
Implementation
BufferRange extend(CellOffset position);
Returns the smallest range that contains both this range and the given
position.
BufferRange extend(CellOffset position);