merge abstract method
Returns the smallest range that contains both this range and the given
range.
Implementation
BufferRange merge(BufferRange range);
Returns the smallest range that contains both this range and the given
range.
BufferRange merge(BufferRange range);