merge method

  1. @override
BufferRangeBlock merge(
  1. BufferRange range
)
override

Returns the smallest range that contains both this range and the given range.

Implementation

@override
BufferRangeBlock merge(BufferRange range) {
  // Enlarge the block such that both borders of the range
  // are within the selected block.
  return extend(range.begin).extend(range.end);
}