CellAttr class abstract

Constructors

CellAttr()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

bold → const int
dashedUnderline → const int
dottedUnderline → const int
doubleUnderline → const int
faint → const int
hyperlinkMarker → const int
hyperlinkMask → const int
hyperlinkShift → const int
inverse → const int
invisible → const int
italic → const int
overline → const int
protected → const int
strikethrough → const int
undercurl → const int
underline → const int
underlineMask → const int
visualMask → const int