CtrlInputHandler class

Translates Ctrl plus a letter into a C0 control character.

Implemented types

Constructors

CtrlInputHandler()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(TerminalKeyboardEvent event) String?
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited