TerminalKeyboardEvent class

The key event received from the keyboard, along with the state of the modifier keys and state of the terminal. Typically consumed by the TerminalInputHandler to produce an escape sequence that can be recognized by the terminal.

Constructors

TerminalKeyboardEvent({required TerminalKey key, required bool shift, required bool ctrl, required bool alt, required TerminalState state, required bool altBuffer, required TerminalTargetPlatform platform, TerminalKeyEventType type = TerminalKeyEventType.press, String? text})

Properties

alt bool
final
altBuffer bool
final
ctrl bool
final
hashCode int
The hash code for this object.
no setterinherited
key TerminalKey
final
platform TerminalTargetPlatform
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shift bool
final
state TerminalState
final
text String?
final
type TerminalKeyEventType
final

Methods

copyWith({TerminalKey? key, bool? shift, bool? ctrl, bool? alt, TerminalState? state, bool? altBuffer, TerminalTargetPlatform? platform, TerminalKeyEventType? type, String? text}) TerminalKeyboardEvent
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited