id property
The id that is used to report a button press or release to the terminal.
Mouse wheel directions use protocol button IDs 64 through 67.
Implementation
final int id;
The id that is used to report a button press or release to the terminal.
Mouse wheel directions use protocol button IDs 64 through 67.
final int id;