TerminalMouseEvent class
Constructors
- TerminalMouseEvent({required TerminalMouseButton button, required TerminalMouseButtonState buttonState, required CellOffset position, CellOffset? pixelPosition, required TerminalState state, required TerminalTargetPlatform platform, bool motion = false, TerminalMouseModifiers modifiers = TerminalMouseModifiers.none})
Properties
-
The button that is pressed or released.
final
-
The current state of the button.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- modifiers → TerminalMouseModifiers
-
final
- motion → bool
-
final
- pixelPosition → CellOffset?
-
The pixel position of the pointer, when the active report mode needs it.
final
- platform → TerminalTargetPlatform
-
The platform of the terminal.
final
- position → CellOffset
-
The position of button state change.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → TerminalState
-
The state of the terminal.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited