onClipboardQuery property
Called when the application requests clipboard contents through OSC 52.
Return null to deny the request. The result may be asynchronous.
Implementation
FutureOr<String?> Function(String selector)? onClipboardQuery;
Called when the application requests clipboard contents through OSC 52.
Return null to deny the request. The result may be asynchronous.
FutureOr<String?> Function(String selector)? onClipboardQuery;