onCurrentDirectoryChange property
Called when the application reports its current directory using OSC 7.
Implementation
void Function(String uri)? onCurrentDirectoryChange;
Called when the application reports its current directory using OSC 7.
void Function(String uri)? onCurrentDirectoryChange;