onEnquiry property
Called when the application sends ENQ (0x05). Return null or an empty string to keep the request silent.
Implementation
String? Function()? onEnquiry;
Called when the application sends ENQ (0x05). Return null or an empty string to keep the request silent.
String? Function()? onEnquiry;