onMouseShapeChange property
Called when the application requests a mouse pointer shape using OSC 22.
Implementation
void Function(String shape)? onMouseShapeChange;
Called when the application requests a mouse pointer shape using OSC 22.
void Function(String shape)? onMouseShapeChange;