onProgressReport property
Called when the application reports task progress using OSC 9;4.
Implementation
void Function(TerminalProgressReport report)? onProgressReport;
Called when the application reports task progress using OSC 9;4.
void Function(TerminalProgressReport report)? onProgressReport;