TerminalContextSignal class final
A hierarchical context update reported through OSC 3008.
Properties
- action → TerminalContextSignalAction
-
final
- bootId → String?
-
no setter
- command → String?
-
no setter
- commandLine → String?
-
no setter
- container → String?
-
no setter
- currentDirectory → String?
-
no setter
- exitStatus → TerminalContextExitStatus?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hostname → String?
-
no setter
- id → String
-
The printable ASCII context identifier.
final
- machineId → String?
-
no setter
-
metadata
→ Map<
String, String> -
All well-formed metadata fields, including fields unknown to xterm2.
no setter
- pid → int?
-
no setter
- pidfdId → int?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId → String?
-
no setter
- signal → String?
-
no setter
- status → int?
-
no setter
- targetHost → String?
-
no setter
- targetUser → String?
-
no setter
- type → TerminalContextType?
-
no setter
- user → String?
-
no setter
- virtualMachine → String?
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited