TerminalContextType enum

Inheritance
Available extensions

Values

boot → const TerminalContextType
container → const TerminalContextType
vm → const TerminalContextType
elevate → const TerminalContextType
chpriv → const TerminalContextType
subcontext → const TerminalContextType
remote → const TerminalContextType
shell → const TerminalContextType
command → const TerminalContextType
app → const TerminalContextType
service → const TerminalContextType
session → const TerminalContextType

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TerminalContextType>
A constant List of the values in this enum, in order of their declaration.