TerminalSemanticPromptState class final
Constructors
- TerminalSemanticPromptState({required TerminalSemanticPromptContent content, int? lastCommandExitCode, String? aid, TerminalSemanticPromptKind? promptKind, TerminalSemanticPromptClickMode? clickMode, TerminalSemanticPromptRedraw? redraw, bool? specialKey, String? commandLine})
-
const
Properties
- aid → String?
-
final
- clickMode → TerminalSemanticPromptClickMode?
-
final
- commandLine → String?
-
final
- content → TerminalSemanticPromptContent
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastCommandExitCode → int?
-
final
- promptKind → TerminalSemanticPromptKind?
-
final
- redraw → TerminalSemanticPromptRedraw?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- specialKey → bool?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited