KittyKeyboardInputHandler class
Translates key presses using Kitty's progressive keyboard protocol.
Flutter exposes text entry separately from logical key presses, so this handler only consumes textual keys when the active protocol mode requires an escape sequence. Functional keys that keep their traditional escape sequence continue through the keytab input handler.
- Implemented types
Constructors
- KittyKeyboardInputHandler()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
TerminalKeyboardEvent event) → String? -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited