TerminalSearchMatch class final
A terminal buffer search match.
Constructors
- TerminalSearchMatch({required BufferRangeLine range, required String text})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- range → BufferRangeLine
-
The matched cell range. The end offset is exclusive.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String
-
The text matched in the terminal buffer.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited